<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - GiveWP tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_GiveWP extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * Give WP Donation
     *
     * @var $donation array
     */
    protected $donation;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {
        global $post;

        $current_page_id      = $post->ID;
        $success_page_id = give_get_option( 'success_page' );

        if ( absint( $current_page_id ) !== absint( $success_page_id ) ) {
            return false;
        }

        return true;
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return function_exists( 'Give' ) && apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_give', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {

        $donation = give_get_purchase_session();

        if ( empty( $donation ) ) {
            return false;
        }

        $this->donation = $donation;
        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {
        return empty( $this->donation ) ? null : $this->donation['price'];
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {

        return empty( $this->donation ) ? null : give_get_option( 'currency' );
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->donation ) ? null : $this->donation['donation_id'];
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {

        if ( empty( $this->donation ) ) {
            return true;
        }

        $tracked = Give()->payment_meta->get_meta(
            $this->get_order_number(),
            "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}",
            true
        );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->donation ) ) {
            return;
        }

        Give()->payment_meta->update_meta(
            $this->get_order_number(),
            "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}",
            true
        );
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'GiveWP';
    }
}
